% [comp_multiple, rxn_multiple] = print_dup(x,pn,name)
% print_dup prints multiple use of the same metabolite or process (reaction or transtort) in the indicated path.
% comp_multiple: list of the compound numbers which appear multiple times in the path, pn
% rxn_multiple: list of the reaction numbers which appear multiple times in the path, pn
% x is a cell consisting of row number sequences of connectivity matrices (CMs). Each row of CMs in this program have 3 elements which are 2 complex numbers each indicating an atom in substrate and the corresponding atom in product, and an integral number indicating the responsible enzyme reaction (reaction number). In a complex number, m + c*i, indicating an atom, m is a metabolite number, and c is an intra-metabolite atom number. rxnnic in this function is column number for reaction number in connectivity matrix.
% pn is a path number indicating a specific sequence described in x.
% name: name of result file
% There should be file_matrix.m, comp_name.csv and rxn_name.csv in the same directory. comp_name.csv is the list of compound names and rxn_name.csv is the list of reaction names.
% btk_connectivity_matrix is for GNU Octave and btk_connectivity_matrix.mat is for both Matlab and GNU Octave. They carry a connectivity matrix, CM.
function [comp_multiple, rxn_multiple] = print_dup(x,pn,name);
if ( nargin == 1 )
     pn = input('Enter Pathway No; ');
     name = 'dup_comp_rxn.txt';
end

if ( exist('OCTAVE_VERSION') ~= 0 )
     load btk_connectivity_matrix;
else
     load btk_connectivity_matrix.mat;
end

CN = file_matrix('comp_name.csv');
comp_name = CN.f_matrix;
cnl = CN.f_length;
RN = file_matrix('rxn_name.csv');
rxn_name = RN.f_matrix;
rnl = RN.f_length;
rxnnic = 3;
fid = fopen(name,'a');
fprintf(fid,'%s\n', ['Pathway No. ', int2str(pn)]);
rs = x{pn,1};
[rsr, rsc] = size(rs);
C = real([CM(rs,1);CM(rs(1,rsc),2)]);
R = CM(rs,rxnnic);
[drCM,drCn]=reduce_matrix(C);
[drRM,drRn]=reduce_matrix(R);
Cs = drCM(find(drCn>=2),:);
Rs = drRM(find(drRn>=2),:);
[Csr,Cscc] = size(Cs);
[Rsr,Rscc] = size(Rs);
i0 = 1;
fprintf(fid,'%s\n', ['Metabolites which appear multiple times:']);
while ( i0 <= Csr )
  fprintf(fid,'%s\n', ['    ',comp_name( Cs(i0,1),1:cnl(Cs(i0,1),1) )]);
  i0 = i0 + 1;
end
i0 = 1;
fprintf(fid,'%s\n', ['Processes (Reactions and Transtort Processes) which appear multiple times:']);
while ( i0 <= Rsr )
  rxnn = Rs(i0,1);
  if ( rxnn > 0 )
     direction = '    > ';
  elseif ( rxnn == 0 )
     direction = '    = ';
  elseif ( rxnn < 0 )
     direction = '    < ';
  end
  fprintf(fid,'%s\n', [direction, rxn_name(abs(rxnn),1:rnl(abs(rxnn),1))]);
  i0 = i0 + 1;
end
comp_multiple = Cs.';
rxn_multiple = Rs.';
fprintf(fid,'%s\n', '');
fclose(fid);
