% print_path(x,pn,name)
% x is a cell consisting of row number sequences of connectivity matrices (CMs). Each row of CMs in this program have 3 elements which are 2 complex numbers each indicating an atom in substrate and the corresponding atom in product, and an integral number indicating the responsible enzyme reaction (reaction number). In a complex number, m + c*i, indicating an atom, m is a metabolite number, and c is an intra-metabolite atom number. rxnnic in this function is column number for reaction number in connectivity matrix.
% pn is a path number indicating a specific sequence described in x.
% name: name of result file
% There should be file_matrix.m, comp_name.csv and rxn_name.csv in the same directory. comp_name.csv is the list of compound names and rxn_name.csv is the list of reaction names.
% btk_connectivity_matrix is for GNU Octave and btk_connectivity_matrix.mat is for both Matlab and GNU Octave. They carry a connectivity matrix, CM.
function print_path(x,pn,name);
if ( nargin == 1 )
     pn = input('Enter Pathway No; ');
     name = 'pathway.txt';
end

if ( exist('OCTAVE_VERSION') ~= 0 )
     load btk_connectivity_matrix;
else
     load btk_connectivity_matrix.mat;
end

CN = file_matrix('comp_name.csv');
comp_name = CN.f_matrix;
cnl = CN.f_length;
RN = file_matrix('rxn_name.csv');
rxn_name = RN.f_matrix;
rnl = RN.f_length;
rxnnic = 3;
fid = fopen(name,'a');
fprintf(fid,'%s\n', ['Pathway No. ', int2str(pn)]);
rs = x{pn,1};
[rsr, rsc] = size(rs);
i0 = 1;
while ( i0 <= rsc )
    n1 = CM(rs(1,i0),1);
    cL = ['[', int2str(i0), '] C', int2str( imag(n1) ), ' ', comp_name( real(n1),1:cnl(real(n1),1) )];
    fprintf(fid,'%s\n', cL);
          rxnn = CM(rs(1,i0),rxnnic);
          if ( rxnn > 0 )
              direction = '    > ';
          elseif ( rxnn == 0 )
              direction = '    = ';
          elseif ( rxnn < 0 )
              direction = '    < ';
          end
          fprintf(fid,'%s\n', [direction, rxn_name(abs(rxnn),1:rnl(abs(rxnn),1))]);
    i0 = i0 + 1;
end
n2 = CM(rs(1,i0-1),2);
cL = ['[', int2str(i0), '] C', int2str( imag(n2) ), ' ', comp_name( real(n2),1:cnl(real(n2),1) )];
fprintf(fid,'%s\n', cL);
fprintf(fid,'%s\n', '');
fclose(fid);
