% [path_no, path_no_dup_met, path_no_dup_rxn] = select_path(cell_of_CM_row_number_seq, selection_method, CM)
% select_path is for selection of pathways.
% cell_of_CM_row_number_seq is a cell consisting of row number sequences of connectivity matrices (CMs). Each row of CMs in this program have 3 elements which are 2 complex numbers each indicating an atom in substrate and the corresponding atom in product, and an integral number indicating the responsible enzyme reaction (reaction number). In a complex number, m + c*i, indicating an atom, m is a metabolite number, and c is an intra-metabolite atom number. rxnnic in this function is column number for reaction number in connectivity matrix. 
% rxn_list is a matrix of reaction numbers which has 2 columns and used for pathway selection. In the selection of pathways, coexsitence of the 2 reactions described on the same row of rxn_list is not allowed.
% Filters (selection methods) are as follows:
% If selection_method is 1, coexistence of a reaction and its reverse reaction is not allowed (Filter 1).
% If selection_method is 2, coexistence of any A and any B is not allowed (Filter 2).
% A: reactions for glycolysis: 
%      hexokinase (glucokinase)
%      phosphofructokinase
%      pyruvate kinase
% B: reactions for gluconeogenesis: 
%      glucose-6-phosphatase
%      fructose-1,6-bisphosphatase
%      phosphoenolpyruvate carboxykinase
% If selection_method is 3, both the coexistences excluded in selection_method 1 and 2 are not allowed (Filter 3).
% The following is a list of reaction numbers for several enzyme reactions.
% 1: hexokinase (glucokinase)
% 3: phosphofructokinase
% 10: pyruvate kinase
% 34: glucose-6-phosphatase
% 35: fructose-1,6-bisphosphatase
% 33: phosphoenolpyruvate carboxykinase
% path_no is a row vector indicating row numbers of cell_of_CM_row_number_seq selected by the indicated selection method.
% path_no_dup_met is a row vector indicating row numbers of cell_of_CM_row_number_seq which are included in path_no and correspond to a pathway having the same metabolite multiple times.
% path_no_dup_rxn is a row vector indicating row numbers of cell_of_CM_row_number_seq which are included in path_no and correspond to a pathway having the same reaction multiple times.

function [path_no, path_no_dup_met, path_no_dup_rxn] = select_path(cell_of_CM_row_number_seq, selection_method, CM);
     rxn_list1 = ...
     [2,-2;
      4,-4;
      5,-5;
      6,-6;
      7,-7;
      8,-8;
      9,-9;
     11,-11;
     15,-15;
     16,-16;
     17,-17;
     19,-19;
     20,-20;
     21,-21;
     22,-22;
     23,-23;
     26,-26;
     27,-27;
     28,-28;
     29,-29;
     30,-30;
     31,-31;
     32,-32];
     rxn_list2 = ...
     [1,34;
      1,35;
      1,33;
      3,34;
      3,35;
      3,33;
     10,34;
     10,35;
     10,33];
if ( selection_method == 1 )
    rxn_list = rxn_list1;
elseif ( selection_method == 2 )
    rxn_list = rxn_list2;
elseif ( selection_method == 3 )
    rxn_list = [rxn_list1; rxn_list2];
end
x = cell_of_CM_row_number_seq;
rxnnic = 3;
[xr, xc] = size(x);
[rxn_listr, rxn_listc] = size(rxn_list);
path_no = [];
path_no_dup_met = [];
path_no_dup_rxn = [];
i2 = 1;
while ( i2 <= xr )
    av = x{i2,1};
    i3 = 1;
    tf = zeros(rxn_listr,1);
    while ( i3 <= rxn_listr )
        if (any(CM(av,rxnnic) == rxn_list(i3,1)) & any(CM(av,rxnnic) == rxn_list(i3,2)));
             k = 1;
        else
             k = 0;
        end
        tf(i3,1) = k;
        i3 = i3 + 1;
    end
    if ( isempty( find(tf == 1) ) == 1 )
        path_no = [path_no, i2];
        [avr,avc] = size(av);
        met_seq = [real(CM(av,1)); real(CM(av(1,avc),2))];
        [met_seqr, met_seqc] = size(met_seq);
        u_met_seq = union(met_seq,met_seq);
        [u_met_seqr, u_met_seqc] = size(u_met_seq);
        if (u_met_seqc > 1)
          u_met_seq = u_met_seq.';
        end
        [u_met_seqr, u_met_seqc] = size(u_met_seq);
        if ( met_seqr ~= u_met_seqr )
          path_no_dup_met = [path_no_dup_met, i2];
        end
        rxn_seq = CM(av,rxnnic);
        [rxn_seqr, rxn_seqc] = size(rxn_seq);
        u_rxn_seq = union(rxn_seq,rxn_seq);
        [u_rxn_seqr, u_rxn_seqc] = size(u_rxn_seq);
        if (u_rxn_seqc > 1)
          u_rxn_seq = u_rxn_seq.';
        end
        [u_rxn_seqr, u_rxn_seqc] = size(u_rxn_seq);
        if ( rxn_seqr ~= u_rxn_seqr )
          path_no_dup_rxn = [path_no_dup_rxn, i2];
        end
    end
    i2 = i2 + 1;
end
